EndSynchronizedUpdate

Struct EndSynchronizedUpdate 

pub struct EndSynchronizedUpdate;
Available on crate feature term only.
A command that instructs the terminal to end a synchronized frame.

Notes

  • Commands must be executed/queued for execution otherwise they do nothing.
  • Use BeginSynchronizedUpdate to enter the alternate screen.

When rendering the screen of the terminal, the Emulator usually iterates through each visible grid cell and renders its current state. With applications updating the screen a at higher frequency this can cause tearing.

This mode attempts to mitigate that.

When the synchronization mode is enabled following render calls will keep rendering the last rendered state. The terminal Emulator keeps processing incoming text and sequences. When the synchronized update mode is disabled again the renderer may fetch the latest screen buffer state again, effectively avoiding the tearing effect by unintentionally rendering in the middle a of an application screen update.

Examples

use std::io::{self, Write};
use crossterm::{execute, terminal::{BeginSynchronizedUpdate, EndSynchronizedUpdate}};

fn main() -> io::Result<()> {
    execute!(io::stdout(), BeginSynchronizedUpdate)?;

    // Anything performed here will not be rendered until EndSynchronizedUpdate is called.

    execute!(io::stdout(), EndSynchronizedUpdate)?;
    Ok(())
}